==> thunderbird_24.4.0+build1.orig.tar.bz2: thunderbird-24.4.0+build1/mozilla/netwerk/socket/nsUDPSocketProvider.cpp <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsUDPSocketProvider.h"

#include "nspr.h"

NS_IMPL_THREADSAFE_ISUPPORTS1(nsUDPSocketProvider, nsISocketProvider)

nsUDPSocketProvider::~nsUDPSocketProvider()
{
}

NS_IMETHODIMP 
nsUDPSocketProvider::NewSocket(int32_t aFamily,
                               const char *aHost, 
                               int32_t aPort, 
                               const char *aProxyHost, 
                               int32_t aProxyPort,
                               uint32_t aFlags,
                               PRFileDesc * *aFileDesc, 
                               nsISupports **aSecurityInfo)
{
    NS_ENSURE_ARG_POINTER(aFileDesc);
  
    PRFileDesc* udpFD = PR_OpenUDPSocket(aFamily);
    if (!udpFD)
        return NS_ERROR_FAILURE;
  
    *aFileDesc = udpFD;
    return NS_OK;
}

NS_IMETHODIMP 
nsUDPSocketProvider::AddToSocket(int32_t aFamily,
                                 const char *aHost,
                                 int32_t aPort,
                                 const char *aProxyHost,
                                 int32_t aProxyPort,
                                 uint32_t aFlags,
                                 struct PRFileDesc * aFileDesc,
                                 nsISupports **aSecurityInfo)
{
    // does not make sense to strap a UDP socket onto an existing socket
    NS_NOTREACHED("Cannot layer UDP socket on an existing socket");
    return NS_ERROR_UNEXPECTED;
}

==> thunderbird_38.6.0+build1.orig.tar.bz2: thunderbird-38.6.0+build1/mozilla/netwerk/socket/nsUDPSocketProvider.cpp <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsUDPSocketProvider.h"

#include "nspr.h"

NS_IMPL_ISUPPORTS(nsUDPSocketProvider, nsISocketProvider)

nsUDPSocketProvider::~nsUDPSocketProvider()
{
}

NS_IMETHODIMP 
nsUDPSocketProvider::NewSocket(int32_t aFamily,
                               const char *aHost, 
                               int32_t aPort, 
                               const char *aProxyHost, 
                               int32_t aProxyPort,
                               uint32_t aFlags,
                               PRFileDesc * *aFileDesc, 
                               nsISupports **aSecurityInfo)
{
    NS_ENSURE_ARG_POINTER(aFileDesc);
  
    PRFileDesc* udpFD = PR_OpenUDPSocket(aFamily);
    if (!udpFD)
        return NS_ERROR_FAILURE;
  
    *aFileDesc = udpFD;
    return NS_OK;
}

NS_IMETHODIMP 
nsUDPSocketProvider::AddToSocket(int32_t aFamily,
                                 const char *aHost,
                                 int32_t aPort,
                                 const char *aProxyHost,
                                 int32_t aProxyPort,
                                 uint32_t aFlags,
                                 struct PRFileDesc * aFileDesc,
                                 nsISupports **aSecurityInfo)
{
    // does not make sense to strap a UDP socket onto an existing socket
    NS_NOTREACHED("Cannot layer UDP socket on an existing socket");
    return NS_ERROR_UNEXPECTED;
}
